@@ -7,6 +7,7 @@ __date__ ="$06/03/2011 00:40:36$"
 from PyQt4 import QtCore, QtGui, QtMaemo5
 import sys
 import os
+import locale
 import pexpect
 import threading
 from graph import Graph
@@ -153,7 +154,7 @@ class About(object):
 "p, li { white-space: pre-wrap; }\n"
 "</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:16pt; font-weight:600;\">SMS Counter</span></p>\n"
-"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.2</span></p>\n"
+"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.3</span></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\"/usr/share/icons/hicolor/64x64/hildon/smscounter.png\" /></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
@@ -212,8 +213,8 @@ class ConfigDialog(QtGui.QDialog):
         self.buttonBox.setObjectName("buttonBox")
         self.gridLayout.addWidget(self.buttonBox, 2, 1, 1, 1)
         self.txtSMSCost = QtGui.QLineEdit(self)
-        self.txtSMSCost.setValidator(QtGui.QDoubleValidator(-1000.0,1000.0,2,self.txtSMSCost))
         self.txtSMSCost.setObjectName("txtSMSCost")
+	self.txtSMSCost.setInputMethodHints(QtCore.Qt.ImhFormattedNumbersOnly)
         self.gridLayout.addWidget(self.txtSMSCost, 0, 1, 1, 1)
         self.label = QtGui.QLabel(self)
         self.label.setObjectName("label")
@@ -222,25 +223,35 @@ class ConfigDialog(QtGui.QDialog):
         self.label_2.setObjectName("label_2")
         self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
         self.txtMinuteCost = QtGui.QLineEdit(self)
-        self.txtMinuteCost.setValidator(QtGui.QDoubleValidator(-1000.0,1000.0,2,self.txtMinuteCost))
         self.txtMinuteCost.setObjectName("txtMinuteCost")
+	self.txtMinuteCost.setInputMethodHints(QtCore.Qt.ImhFormattedNumbersOnly)
         self.gridLayout.addWidget(self.txtMinuteCost, 1, 1, 1, 1)
 
         self.retranslateUi(self)
         QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), self.accept)
         QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), self.reject)
+	QtCore.QObject.connect(self.txtSMSCost, QtCore.SIGNAL("editingFinished()"), self.validateTxtSMSCost)
+	QtCore.QObject.connect(self.txtMinuteCost, QtCore.SIGNAL("editingFinished()"), self.validateTxtMinuteCost)
         QtCore.QMetaObject.connectSlotsByName(self)
-
-        self.txtSMSCost.setText(str(ConfigData.sms_cost))
-        self.txtMinuteCost.setText(str(ConfigData.call_minute_cost))
+	
+        self.txtSMSCost.setText(locale.str(ConfigData.sms_cost))
+        self.txtMinuteCost.setText(locale.str(ConfigData.call_minute_cost))
     def retranslateUi(self, Dialog):
         Dialog.setWindowTitle(QtGui.QApplication.translate("Dialog", "Configuration", None, QtGui.QApplication.UnicodeUTF8))
         self.label.setText(QtGui.QApplication.translate("Dialog", "SMS Cost:", None, QtGui.QApplication.UnicodeUTF8))
         self.label_2.setText(QtGui.QApplication.translate("Dialog", "Minute Cost:", None, QtGui.QApplication.UnicodeUTF8))
-
+    def validateTxtSMSCost(self):
+        self.validateLineEdit(self.txtSMSCost,ConfigData.sms_cost)
+    def validateTxtMinuteCost(self):
+	self.validateLineEdit(self.txtMinuteCost,ConfigData.call_minute_cost)
+    def validateLineEdit(self,le,defaultValue):
+	try:
+	    le.setText(locale.str(locale.atof(le.text())))
+	except:
+	    le.setText(locale.str(defaultValue))
     def accept(self):
-        ConfigData.sms_cost=float(self.txtSMSCost.text())
-        ConfigData.call_minute_cost=float(self.txtMinuteCost.text())
+        ConfigData.sms_cost=locale.atof(self.txtSMSCost.text())
+        ConfigData.call_minute_cost=locale.atof(self.txtMinuteCost.text())
         ConfigData.save()
         QtGui.QDialog.accept(self)
 
@@ -468,20 +479,20 @@ class SMSWidget(QtGui.QWidget):
         rr=0
         if receivedS>0:
             rr=round(float(Spam)/receivedS*100,2)
-        Spam=str(Spam)+" ("+str(rr)+"%)"
+        Spam=str(Spam)+" ("+locale.str(rr)+"%)"
         rr=0
         if totS>0:
             rr=round(float(receivedS)/totS*100,2)
-        receivedS=str(receivedS)+" ("+str(rr)+"%)"
+        receivedS=str(receivedS)+" ("+locale.str(rr)+"%)"
         rr=0
         if totS>0:
             rr=round(float(sentS)/totS*100,2)
-        sentS=str(sentS)+" ("+str(rr)+"%)"
+        sentS=str(sentS)+" ("+locale.str(rr)+"%)"
         totS=str(totS)
         self.lblTotSMS.setText("Total SMS: "+totS)
         self.lblReceivedSMS.setText("Received SMS: "+receivedS)
         self.lblSentSMS.setText("Sent SMS: "+sentS)
-        self.lblSMSCost.setText("Cost: "+str(costS))
+        self.lblSMSCost.setText("Cost: "+locale.str(costS))
         self.lblSpamSMS.setText("Spam: "+Spam)
 
 class CallsWidget(QtGui.QWidget):
@@ -558,15 +569,15 @@ class CallsWidget(QtGui.QWidget):
 	rr=0
         if totC>0:
             rr=round(float(receivedC)/totC*100,2)
-        receivedC=str(receivedC)+" ("+str(rr)+"%)"
+        receivedC=str(receivedC)+" ("+locale.str(rr)+"%)"
 	rr=0
         if totC>0:
             rr=round(float(missedC)/totC*100,2)
-        missedC=str(missedC)+" ("+str(rr)+"%)"
+        missedC=str(missedC)+" ("+locale.str(rr)+"%)"
         rr=0
         if totC>0:
             rr=round(float(sentC)/totC*100,2)
-        sentC=str(sentC)+" ("+str(rr)+"%)"
+        sentC=str(sentC)+" ("+locale.str(rr)+"%)"
         totC=str(totC)
 	self.lblTotCalls.setText("Total: "+totC)
         self.lblReceivedCalls.setText("Received: "+receivedC)
@@ -575,7 +586,7 @@ class CallsWidget(QtGui.QWidget):
         self.lblMadeCalls.setText("Made: "+sentC)
         self.lblMCallsDuration.setText("Duration: "+timeFormat(secMCalls))
         self.lblTotMinutes.setText("Total duration: "+timeFormat(secRCalls+secMCalls))
-        self.lblMCallsCost.setText("Cost: "+str(secMCalls/60*ConfigData.call_minute_cost))
+        self.lblMCallsCost.setText("Cost: "+locale.str(secMCalls/60*ConfigData.call_minute_cost))
 	self.lblMissedCalls.setText("Missed: "+missedC)
         
 class DataGraph(QtGui.QWidget):
@@ -607,6 +618,7 @@ class Main(QtGui.QWidget):
         self.mw=MainWidget()
         self.mw.setupUi(self)
 if __name__ == "__main__":
+    locale.setlocale(locale.LC_ALL, '')
     app = QtGui.QApplication(sys.argv)
     qb = Main()
     qb.show()
